@@ -125,6 +125,7 @@ list_iterate (p11_enumerate *ex,
 		if (attr && attr->pValue && attr->ulValueLen) {
 			string = strndup (attr->pValue, attr->ulValueLen);
 			printf ("    label: %s\n", string);
+			free (string);
 		}
 
 		if (p11_attrs_find_bool (ex->attrs, CKA_X_DISTRUSTED, &val) && val)
@@ -229,10 +230,7 @@ p11_trust_list (int argc,
 		}
 	}
 
-	argc -= optind;
-	argv += optind;
-
-	if (argc != 0) {
+	if (argc - optind != 0) {
 		p11_message ("extra arguments passed to command");
 		exit (2);
 	}
